@@ -1,16 +1,5 @@
 package CGI::Panel::MainPanel;
 
-##################
-
-=head2 THIS SUB-CLASS IS NOW DEPRECATED!!!
-
-IT IS INCLUDED HERE FOR BACKWARD COMPATIBILITY
-AND WILL BE REMOVED FROM FUTURE RELEASES!
-
-=cut
-
-##################
-
 use strict;
 use CGI;
 use CGI::Panel;
@@ -21,7 +10,7 @@ use Apache::Session::File;
 BEGIN {
 	use Exporter ();
 	use vars qw ($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-	$VERSION     = 0.95;
+	$VERSION     = 0.96;
 	@ISA         = qw (Exporter CGI::Panel);
 	@EXPORT      = qw ();
 	@EXPORT_OK   = qw ();
@@ -36,8 +25,11 @@ CGI::Panel::MainPanel - Main panel superclass for CGI::Panel-based applications
 
 =head1 SYNOPSIS
 
+=head2 THIS SUB-CLASS IS NOW DEPRECATED!!!
+
 The main panel of an application is now just sub-classed from CGI::Panel.  Please
-adjust your code accordingly as this sub-class is now deprecated.
+adjust your code accordingly as this sub-class is now deprecated.  This package
+is included for backward-compatibility and will be removed in a future release.
 
 =cut
 
